// Licensed to Cloudera, Inc. under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  Cloudera, Inc. licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
package com.cloudera.api.model;

import java.util.Date;
import java.util.Map;

import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;

import com.google.common.base.Objects;
import com.google.common.base.Preconditions;

/**
 * Represents a Yarn application
 */
@XmlRootElement(name = "yarnApplication")
public class ApiYarnApplication {

  private String applicationId;
  private String name;
  private Date startTime;
  private Date endTime;
  private String user;
  private String pool;
  private String state;
  private Double progress;
  private ApiMr2AppInformation mr2AppInfo;
  private Map<String, String> attributes;

  public ApiYarnApplication() {
    // For JAX-B
  }

  public ApiYarnApplication(
      String applicationId,
      String name,
      Date startTime,
      Date endTime,
      String user,
      String pool,
      String state,
      Double progress,
      ApiMr2AppInformation mr2AppInfo,
      Map<String, String> attributes) {
    Preconditions.checkNotNull(applicationId);
    Preconditions.checkNotNull(name);
    Preconditions.checkNotNull(startTime);
    Preconditions.checkNotNull(user);
    Preconditions.checkNotNull(attributes);
    this.applicationId = applicationId;
    this.name = name;
    this.startTime = startTime;
    this.endTime = endTime;
    this.user = user;
    this.pool = pool;
    this.state = state;
    this.progress = progress;
    this.attributes = attributes;
    this.mr2AppInfo = mr2AppInfo;
  }

  /** The application id. */
  @XmlElement
  public String getApplicationId() {
    return applicationId;
  }

  public void setApplicationId(String applicationId) {
    this.applicationId = applicationId;
  }

  /** The name of the application. */
  @XmlElement
  public String getName() {
    return name;
  }

  public void setName(String name) {
    this.name = name;
  }

  /** The time the application was submitted. */
  @XmlElement
  public Date getStartTime() {
    return startTime;
  }

  public void setStartTime(Date startTime) {
    this.startTime = startTime;
  }

  /**
   * The time the application finished. If the application hasn't finished
   * this will return null.
   */
  @XmlElement
  public Date getEndTime() {
    return endTime;
  }

  public void setEndTime(Date endTime) {
    this.endTime = endTime;
  }

  /** The user who submitted the application. */
  @XmlElement
  public String getUser() {
    return user;
  }

  public void setUser(String user) {
    this.user = user;
  }

  /** The queue the application was submitted to. */
  @XmlElement
  public String getPool() {
    return pool;
  }

  public void setPool(String pool) {
    this.pool = pool;
  }

  /**
   * The progress, as a percentage, the application has made. This is only
   * set if the application is currently executing.
   */
  @XmlElement
  public Double getProgress() {
    return progress;
  }

  public void setProgress(Double progress) {
    this.progress = progress;
  }

  /**
   * A map of additional application attributes which is generated by
   * Cloudera Manager. For example MR2 job counters are exposed as key/value
   * pairs here. For more details see the Cloudera Manager documentation.
   */
  public Map<String, String> getAttributes() {
    return attributes;
  }

  public void setAttributes(Map<String, String> attributes) {
    this.attributes = attributes;
  }

  public ApiMr2AppInformation getMr2AppInformation() {
    return mr2AppInfo;
  }

  public void setMr2AppInformation(ApiMr2AppInformation mr2AppInfo) {
    this.mr2AppInfo = mr2AppInfo;
  }

  @XmlElement
  public String getState() {
    return state;
  }

  public void setState(String state) {
    this.state = state;
  }

  @Override
  public String toString() {
    return Objects.toStringHelper(this)
        .add("name", name)
        .add("startTime", startTime)
        .add("endTime", endTime)
        .add("user", user)
        .add("pool", pool)
        .add("state", state)
        .add("progress", progress)
        .add("attributes", attributes)
        .add("mr2AppInfo", mr2AppInfo)
        .toString();
  }
}
