// Licensed to Cloudera, Inc. under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  Cloudera, Inc. licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
package com.cloudera.api.v3;

import com.cloudera.api.model.ApiHostRef;
import com.cloudera.api.model.ApiHostRefList;
import com.cloudera.api.v2.ClustersResourceV2;

import javax.ws.rs.Consumes;
import javax.ws.rs.DELETE;
import javax.ws.rs.GET;
import javax.ws.rs.POST;
import javax.ws.rs.Path;
import javax.ws.rs.PathParam;
import javax.ws.rs.Produces;
import javax.ws.rs.core.MediaType;

import static com.cloudera.api.Parameters.CLUSTER_NAME;
import static com.cloudera.api.Parameters.HOST_ID;

@Consumes({ MediaType.APPLICATION_JSON })
@Produces({ MediaType.APPLICATION_JSON })
public interface ClustersResourceV3 extends ClustersResourceV2 {

  /**
   * @return The services resource handler.
   */
  @Override
  @Path("/{clusterName}/services")
  public ServicesResourceV3 getServicesResource(
      @PathParam(CLUSTER_NAME) String clusterName);

  /**
   * @return the parcels resource handler.
   */
  @Path("/{clusterName}/parcels")
  public ParcelsResource getParcelsResource(
      @PathParam(CLUSTER_NAME) String clusterName);

  /**
   * @return The host templates handler.
   */
  @Path("/{clusterName}/hostTemplates")
  public HostTemplatesResource getHostTemplatesResource(
      @PathParam(CLUSTER_NAME) String clusterName);

  /**
   * @return the hosts associated with the cluster
   */
  @GET
  @Path("/{clusterName}/hosts")
  public ApiHostRefList listHosts(
      @PathParam(CLUSTER_NAME) String clusterName);

  /**
   * @return the newly added hosts to the cluster.
   *         if a host is already a member,
   *         it will be excluded from the list
   */
  @POST
  @Path("/{clusterName}/hosts")
  public ApiHostRefList addHosts(
      @PathParam(CLUSTER_NAME) String clusterName,
      ApiHostRefList hosts);

  /**
   * @return the host that was unassociated with the cluster.
   *         if the host is not part of the cluster, return null
   */
  @DELETE
  @Path("/{clusterName}/hosts/{hostId}")
  public ApiHostRef removeHost(
      @PathParam(CLUSTER_NAME) String clusterName,
      @PathParam(HOST_ID) String hostId);

  /**
   * @return all the hosts that were unassociated with the cluster
   */
  @DELETE
  @Path("/{clusterName}/hosts")
  public ApiHostRefList removeAllHosts(
      @PathParam(CLUSTER_NAME) String clusterName);
}
